feePerVb property
- @TagNumber.new(6)
The amount of satoshis per vbyte ("satVb"), used for fee calculation.
Can be satoshis per byte ("satB") ONLY when transaction does not contain segwit UTXOs.
In most cases, the fee rate is a positive integer, but it can be zero when fee validation is not necessary (InputSelector.UseAll),
or the transaction is free or it contains a miner subsidy UTXO (eg. coinbase transaction).
Implementation
@$pb.TagNumber(6)
$fixnum.Int64 get feePerVb => $_getI64(5);
- @TagNumber.new(6)
Implementation
@$pb.TagNumber(6)
set feePerVb($fixnum.Int64 value) => $_setInt64(5, value);