auxiliaryData property

  1. @TagNumber.new(12)
List<int> get auxiliaryData

Optional auxiliary data (e.g. CIP-20 memo metadata), already CBOR-encoded. If set, its Blake2b-256 hash is committed in the transaction body (key 7, auxiliary_data_hash) and these bytes are embedded as the signed transaction's auxiliary_data, so the caller does not append anything. The automatic fee planner includes this field in its size/fee estimate.

Implementation

@$pb.TagNumber(12)
$core.List<$core.int> get auxiliaryData => $_getN(11);
  1. @TagNumber.new(12)
set auxiliaryData (List<int> value)

Implementation

@$pb.TagNumber(12)
set auxiliaryData($core.List<$core.int> value) => $_setBytes(11, value);