Message_VoteOption class

VoteOption enumerates the valid vote options for a given governance proposal.

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
This enum's name, as specified in the .proto file.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
This enum's integer value, as specified in the .proto file.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns this enum's name or the value if names are not represented.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

valueOf(int value) Message_VoteOption?

Constants

ABSTAIN → const Message_VoteOption
ABSTAIN defines an abstain vote option.
NO → const Message_VoteOption
NO defines a no vote option.
NO_WITH_VETO → const Message_VoteOption
NO_WITH_VETO defines a no with veto vote option.
UNSPECIFIED_ → const Message_VoteOption
_UNSPECIFIED defines a no-op vote option.
values → const List<Message_VoteOption>
YES → const Message_VoteOption
YES defines a yes vote option.