TransactionMode class

Transaction type

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
This enum's name, as specified in the .proto file.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
This enum's integer value, as specified in the .proto file.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns this enum's name or the value if names are not represented.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

valueOf(int value) TransactionMode?

Constants

Enveloped → const TransactionMode
Enveloped transaction EIP2718 (with type 0x2), fee is according to EIP1559 (base fee, inclusion fee, ...)
Legacy → const TransactionMode
Legacy transaction, pre-EIP2718/EIP1559; for fee gasPrice/gasLimit is used
SetCode → const TransactionMode
EIP-7702 transaction (with type 0x4); allows to set the code of a contract for an EOA. Note that SetCode transaction extends Enveloped transaction. https://eips.ethereum.org/EIPS/eip-7702
UserOp → const TransactionMode
EIP4337-compatible UserOperation
values → const List<TransactionMode>