AbiError class

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
This enum's name, as specified in the .proto file.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
This enum's integer value, as specified in the .proto file.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns this enum's name or the value if names are not represented.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

valueOf(int value) AbiError?

Constants

Error_abi_mismatch → const AbiError
Unexpected function signature or ABI mismatch.
Error_decoding_data → const AbiError
Invalid encoded data.
Error_empty_type → const AbiError
Invalid empty type. For example, bytes0, address0.
Error_internal → const AbiError
Internal error.
Error_invalid_abi → const AbiError
Invalid ABI.
Error_invalid_address_value → const AbiError
Invalid address value.
Error_invalid_param_type → const AbiError
Invalid parameter type.
Error_invalid_uint_value → const AbiError
Invalid UInt value.
Error_missing_param_type → const AbiError
Missing parameter type.
Error_missing_param_value → const AbiError
Missing parameter value.
OK → const AbiError
This is the OK case, with value=0
values → const List<AbiError>