transactionJson property

  1. @TagNumber.new(1)
String get transactionJson

Resulting transaction. Note that the amount may be different than the requested amount to account for fees and available funds.

Implementation

@$pb.TagNumber(1)
$core.String get transactionJson => $_getSZ(0);
  1. @TagNumber.new(1)
set transactionJson (String value)

Implementation

@$pb.TagNumber(1)
set transactionJson($core.String value) => $_setString(0, value);