Utility_BatchKind class

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
This enum's name, as specified in the .proto file.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
This enum's integer value, as specified in the .proto file.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns this enum's name or the value if names are not represented.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

valueOf(int value) Utility_BatchKind?

Constants

Atomic → const Utility_BatchKind
Batch multiple calls and execute them in a single atomic transaction. The whole transaction will rollback if any of the calls fail.
Optimistic → const Utility_BatchKind
Batch multiple calls. Unlike Batch this will continue even if one of the calls failed.
StopOnError → const Utility_BatchKind
Batch multiple calls, stoping on the first error.
values → const List<Utility_BatchKind>