amounts property
- @TagNumber.new(3)
The amounts to be transferred to recipients, following the same order.
Implementation
@$pb.TagNumber(3)
$pb.PbList<$fixnum.Int64> get amounts => $_getList(2);
The amounts to be transferred to recipients, following the same order.
@$pb.TagNumber(3)
$pb.PbList<$fixnum.Int64> get amounts => $_getList(2);