inputCoins property
The Sui coins to be used in this transaction, including the coin for gas payment.
Implementation
@$pb.TagNumber(1)
$pb.PbList<ObjectRef> get inputCoins => $_getList(0);
The Sui coins to be used in this transaction, including the coin for gas payment.
@$pb.TagNumber(1)
$pb.PbList<ObjectRef> get inputCoins => $_getList(0);