toAmountLimit property

  1. @TagNumber.new(8)
String get toAmountLimit

Optional minimum accepted destination amount. Actual destination amount will depend on current rates, limit amount can be used to prevent using very unfavorable rates. The default is 0 - no price limit.

Implementation

@$pb.TagNumber(8)
$core.String get toAmountLimit => $_getSZ(7);
  1. @TagNumber.new(8)
set toAmountLimit (String value)

Implementation

@$pb.TagNumber(8)
set toAmountLimit($core.String value) => $_setString(7, value);