copyWith method

  1. @Deprecated('See https://github.com/google/protobuf.dart/issues/998.')
FreezeBalanceV2Contract copyWith(
  1. void updates(
    1. FreezeBalanceV2Contract
    )
)

Apply updates to a copy of this message.

Makes a writable shallow copy of this message, applies the updates to it, and marks the copy read-only before returning it.

Implementation

@$core.Deprecated('See https://github.com/google/protobuf.dart/issues/998.')
FreezeBalanceV2Contract copyWith(
        void Function(FreezeBalanceV2Contract) updates) =>
    super.copyWith((message) => updates(message as FreezeBalanceV2Contract))
        as FreezeBalanceV2Contract;