copyWith method

  1. @Deprecated('See https://github.com/google/protobuf.dart/issues/998.')
VoteWitnessContract_Vote copyWith(
  1. void updates(
    1. VoteWitnessContract_Vote
    )
)

Apply updates to a copy of this message.

Makes a writable shallow copy of this message, applies the updates to it, and marks the copy read-only before returning it.

Implementation

@$core.Deprecated('See https://github.com/google/protobuf.dart/issues/998.')
VoteWitnessContract_Vote copyWith(
        void Function(VoteWitnessContract_Vote) updates) =>
    super.copyWith((message) => updates(message as VoteWitnessContract_Vote))
        as VoteWitnessContract_Vote;